pub enum BezierRetainedOverlapOrientation2 {
Same,
Opposite,
}Expand description
Orientation of two refined fragments that carry the same overlap image.
Variants
Same
The two overlap subfragments have equal start and end endpoint order.
Opposite
The second overlap subfragment has the opposite endpoint order.