RetainedPlanarFacePointLocation2

Enum RetainedPlanarFacePointLocation2 

pub enum RetainedPlanarFacePointLocation2 {
    SurfaceMismatch,
    Outside,
    Boundary,
    Inside,
}
Point classification result for a retained planar face.

Variants



SurfaceMismatch

The query was made against a different retained support surface.



Outside

The UV point is outside the retained face.



Boundary

The UV point lies on a material or hole trim boundary.



Inside

The UV point is inside the retained face.

Implementations

Source

impl RetainedPlanarFacePointLocation2

pub const fn is_trim_classification(self) -> bool

Returns true when the query reached an exact inside/outside/boundary result.