pub struct BezierAlgebraicPointImage2 { /* private fields */ }Expand description
Exact algebraic image of a Bezier point.
Implementations
Sourceimpl BezierAlgebraicPointImage2
impl BezierAlgebraicPointImage2
Sourcepub const fn status(&self) -> BezierAlgebraicImageStatus
pub const fn status(&self) -> BezierAlgebraicImageStatus
Returns the final construction status.
Sourcepub const fn parameter(&self) -> &AlgebraicRootRepresentation
pub const fn parameter(&self) -> &AlgebraicRootRepresentation
Returns the represented Bezier parameter used as the source root.
Sourcepub const fn x(&self) -> Option<&BezierAlgebraicCoordinateImage>
pub const fn x(&self) -> Option<&BezierAlgebraicCoordinateImage>
Returns the x coordinate image when construction reached it.
Sourcepub const fn y(&self) -> Option<&BezierAlgebraicCoordinateImage>
pub const fn y(&self) -> Option<&BezierAlgebraicCoordinateImage>
Returns the y coordinate image when construction reached it.