pub struct BezierAlgebraicRationalCoordinateImage { /* private fields */ }Expand description
One exact rational-function coordinate image at an algebraic parameter.
Implementations
Sourceimpl BezierAlgebraicRationalCoordinateImage
impl BezierAlgebraicRationalCoordinateImage
Sourcepub fn numerator_coefficients(&self) -> &[Real]
pub fn numerator_coefficients(&self) -> &[Real]
Returns numerator coefficients in ascending powers of the source Bezier parameter.
Sourcepub fn denominator_coefficients(&self) -> &[Real]
pub fn denominator_coefficients(&self) -> &[Real]
Returns denominator coefficients in ascending powers of the source Bezier parameter.
Sourcepub const fn report(&self) -> &AlgebraicRootRationalImageReport
pub const fn report(&self) -> &AlgebraicRootRationalImageReport
Returns the exact rational-image report produced by hypersolve.
Sourcepub fn representation(&self) -> Option<&AlgebraicRootRepresentation>
pub fn representation(&self) -> Option<&AlgebraicRootRepresentation>
Returns the represented coordinate when the image was constructed.