pub struct Similarity2 { /* private fields */ }Expand description
A 2D affine transform whose linear part is a nonsingular similarity.
Implementations
Sourceimpl Similarity2
impl Similarity2
Sourcepub fn try_from_f64_affine(
a: f64,
b: f64,
d: f64,
e: f64,
xoff: f64,
yoff: f64,
tolerance: f64,
) -> CurveResult<Self>
pub fn try_from_f64_affine( a: f64, b: f64, d: f64, e: f64, xoff: f64, yoff: f64, tolerance: f64, ) -> CurveResult<Self>
Constructs a planar similarity from finite affine entries.
The transform is:
x' = a*x + b*y + xoff
y' = d*x + e*y + yoffThe finite validation tolerance is only used to accept API-boundary matrix entries as a similarity. Once accepted, all transformed geometry is built with hyperreal coefficients.
Sourcepub const fn reverses_orientation(&self) -> bool
pub const fn reverses_orientation(&self) -> bool
Returns true when the transform reverses orientation.
Sourcepub fn transform_point(&self, point: &Point2) -> Point2
pub fn transform_point(&self, point: &Point2) -> Point2
Transforms a point with hyperreal arithmetic.